package carton-miou

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Carton_miou_bundleSource

Read and produce git-bundle files.

Sourceval of_packs : cfg:Carton_miou_unix.config -> digest:Carton.First_pass.digest -> sort:Carton_miou_unix.sort -> ?level:int -> Bundle.t -> Fpath.t list -> string Seq.t

of_packs ~cfg ~digest ~sort hdr packs is the bundle stream made of the header hdr followed by a PACK re-delta-ified from the given packs (see Carton_miou_unix.merge).

Sourceval read : ?ref_length:int -> Fpath.t -> (Bundle.t * string Seq.t, [> `Msg of string ]) result

read filename is the header of the bundle filename and the stream of the PACK bytes it contains.

Note: the returned sequence is not persistent.

Sourceval split : ?ref_length:int -> Fpath.t -> pack:Fpath.t -> (Bundle.t, [> `Msg of string ]) result

split filename ~pack extracts the PACK contained into the bundle filename to pack and returns the header of the bundle.

Note: if the bundle has prerequisites (Bundle.is_thin), the extracted PACK is thin and the missing sources must be given back to Carton as Carton.location.Extern objects.

/

Sourceval save : Fpath.t -> string Seq.t -> unit